@@ -1,6 +1,7 @@
 """ Errors Page """
 
-from flask import render_template, Blueprint
+from flask import Blueprint
+from textflow.view.base import render_template
 
 view = Blueprint('errors_view', __name__)
 
